Androssy class

Properties

cachedNetworkImageBuilder AndrossyBuilder<AndrossyNetworkImageConfig>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
svgImageBuilder AndrossyBuilder<AndrossySvgPictureConfig>?
final
textConverter AndrossyConverter<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

i Androssy
no setter
iOrNull Androssy?
no setter

Static Methods

init({AndrossyBuilder<AndrossyNetworkImageConfig>? cachedNetworkImageBuilder, AndrossyBuilder<AndrossySvgPictureConfig>? svgBuilder, AndrossyConverter<String>? textConverter}) → void