DockedArcSides class

Constructors

DockedArcSides({DockedArcSide left = DockedArcSide.none, DockedArcSide top = DockedArcSide.none, DockedArcSide right = DockedArcSide.none, DockedArcSide bottom = DockedArcSide.none, DockedArcSide topLeft = DockedArcSide.outer, DockedArcSide topRight = DockedArcSide.outer, DockedArcSide bottomLeft = DockedArcSide.outer, DockedArcSide bottomRight = DockedArcSide.outer})
const

Properties

bottom DockedArcSide
final
bottomLeft DockedArcSide
final
bottomRight DockedArcSide
final
hashCode int
The hash code for this object.
no setterinherited
left DockedArcSide
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top DockedArcSide
final
topLeft DockedArcSide
final
topRight DockedArcSide
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited