LifecycleMixin<T extends StatefulWidget> mixin
A mixin that provides Android-like lifecycle methods for Flutter StatefulWidgets
- Superclass constraints
- State<
T>
- State<
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- endTime → Duration
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initializedTime → Duration
-
no setter
- isInitialized → bool
-
Whether onCreate initialization is complete
no setter
- isResumed → bool
-
Whether the widget is currently in resumed state
no setter
- isVisible → bool
-
Whether the widget is currently visible
no setter
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → T
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
override
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
override
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
override
-
didUpdateWidget(
covariant T oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCreate(
) → Future< void> - Called when the widget is first created. This is the place to:
-
onDestroy(
) → void - Called when the widget is about to be destroyed. Use this to:
-
onPause(
) → void - Called when the widget is no longer in focus but may be visible. Use this to:
-
onReady(
) → void - Called when onCreate initialization is complete This is the ideal place to:
-
onRestart(
) → void - Called when the widget becomes visible again after being stopped. Use this to:
-
onResume(
) → void - Called when the widget is fully visible and interactive. Use this to:
-
onStart(
) → void - Called when the widget becomes visible to the user. This is where you should:
-
onStop(
) → void - Called when the widget is no longer visible. Use this to:
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited