AndrossyButtonProperty<T> class

Constructors

AndrossyButtonProperty({T? activated, T? disabled, T? enabled, T? loading})
const
AndrossyButtonProperty.all(T value)
const

Properties

activated → T?
final
disabled → T?
final
enabled → T?
final
hashCode int
The hash code for this object.
no setterinherited
loading → T?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

from(AndrossyButtonPropertyState state) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited