AndrossyButtonSkeleton class

Inheritance

Constructors

AndrossyButtonSkeleton({Key? key, double? width, double? height, BoxConstraints? constraints, EdgeInsets? padding, dynamic icon, IconAlignment iconAlignment = IconAlignment.end, Color? iconColor, bool iconColorAsRoot = false, bool iconFlexible = false, bool iconOnly = false, double iconSize = 24, double? iconSpace, Widget? indicator, Color? indicatorColor, double? indicatorSize, double? indicatorStrokeWidth, bool indicatorVisible = false, String? text, bool textAllCaps = false, bool textCenter = false, Color? textColor, double? textSize, TextStyle? textStyle})
const

Properties

alignment Alignment?
no setter
constraints BoxConstraints?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
icon → dynamic
final
iconAlignment IconAlignment
final
iconColor Color?
final
iconColorAsRoot bool
final
iconFlexible bool
final
iconOnly bool
final
iconSize double
final
iconSpace double?
final
indicator Widget?
final
indicatorColor Color?
final
indicatorSize double?
final
indicatorStrokeWidth double?
final
indicatorVisible bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
textAllCaps bool
final
textCenter bool
final
textColor Color?
final
textSize double?
final
textStyle TextStyle?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited