AndrossyDataResponse<T extends Object?> class

Constructors

AndrossyDataResponse.call(T? data)
const
AndrossyDataResponse.failure(Object? error)
const
AndrossyDataResponse.loader(bool loading)
const

Properties

data → T?
final
error String
final
hashCode int
The hash code for this object.
no setterinherited
loading bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited