AndrossyField class

Inheritance

Constructors

AndrossyField({Key? key, Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, EdgeInsets? contentPadding, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, AndrossyFieldProperty<TextStyle?>? footerStyle, FloatingVisibility? footerVisibility, double? height, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, IndicatorAlignment? indicatorAlignment, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, String? loadingText, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, double? width, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldContextMenuBuilder? contextMenuBuilder, AndrossyFieldProperty<Color?>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, TextDirection? textDirection, Brightness? keyboardAppearance, bool? enabled, bool? autoDisposeMode, String? characters, AndrossyFieldProperty? drawableEnd, AndrossyFieldDrawableBuilder? drawableEndBuilder, bool? drawableEndVisible, AndrossyFieldTweenProperty? drawableEye, AndrossyFieldProperty? drawableStart, AndrossyFieldDrawableBuilder? drawableStartBuilder, bool? drawableStartVisible, String? errorText, String? floatingText, String? helperText, String? hintText, Widget? indicator, bool? indicatorVisible, String? ignorableCharacters, int? maxCharacters, bool? maxCharactersAsLimit, int? minCharacters, List<TextInputFormatter>? inputFormatters, String? text, bool? autocorrect, List<String>? autofillHints, bool? autoFocus, TextEditingController? controller, bool? expands, TextInputAction? inputAction, TextInputType? inputType, int? maxLines, int? minLines, bool? obscureText, bool? readOnly, String? restorationId, ScrollController? scrollController, bool? showCursor, UndoHistoryController? undoController, AndrossyFieldPrivateCommandListener? onAppPrivateCommand, AndrossyFieldVoidListener? onEditingComplete, AndrossyFieldSubmitListener? onSubmitted, AndrossyFieldTapOutsideListener? onTapOutside, OnAndrossyFieldErrorCheck? onCheck, OnAndrossyFieldChanged? onChanged, OnAndrossyFieldError? onError, OnAndrossyFieldValid? onValid, OnAndrossyFieldValidator? onValidator})
const

Properties

animationCurve Curve?
final
animationDuration Duration?
final
autocorrect bool?
TEXT FIELD LOCAL PROPERTIES
final
autoDisposeMode bool?
final
autofillHints List<String>?
final
autoFocus bool?
final
backgroundColor AndrossyFieldProperty<Color?>?
final
borderColor AndrossyFieldProperty<Color?>?
final
borderRadius AndrossyFieldProperty<BorderRadius?>?
final
borderWidth AndrossyFieldTweenProperty<double?>?
final
characters String?
final
clipBehavior Clip?
TEXT FIELD GLOBAL PROPERTIES
final
constraints BoxConstraints?
final
contentInsertionConfiguration ContentInsertionConfiguration?
final
contentPadding EdgeInsets?
final
contextMenuBuilder AndrossyFieldContextMenuBuilder?
final
controller TextEditingController?
final
counterStyle AndrossyFieldProperty<TextStyle?>?
final
counterVisibility FloatingVisibility?
final
cursorColor AndrossyFieldProperty<Color?>?
final
cursorHeight double?
final
cursorOpacityAnimates bool?
final
cursorRadius Radius?
final
cursorWidth double?
final
decoration AndrossyFieldProperty<BoxDecoration?>?
final
dragStartBehavior DragStartBehavior?
final
drawableEnd AndrossyFieldProperty?
final
drawableEndBuilder AndrossyFieldDrawableBuilder?
final
drawableEndPadding AndrossyFieldProperty<double?>?
final
drawableEndSize AndrossyFieldProperty<double?>?
final
drawableEndTint AndrossyFieldProperty<Color?>?
final
drawableEndVisible bool?
final
drawableEye AndrossyFieldTweenProperty?
final
drawableStart AndrossyFieldProperty?
final
drawableStartBuilder AndrossyFieldDrawableBuilder?
final
drawableStartPadding AndrossyFieldProperty<double?>?
final
drawableStartSize AndrossyFieldProperty<double?>?
final
drawableStartTint AndrossyFieldProperty<Color?>?
final
drawableStartVisible bool?
final
enabled bool?
LOCAL PROPERTIES
final
enableIMEPersonalizedLearning bool?
final
enableInteractiveSelection bool?
final
enableSuggestions bool?
final
errorColor Color?
final
errorStyle AndrossyFieldProperty<TextStyle?>?
final
errorText String?
final
expands bool?
final
floatingAlignment Alignment?
final
floatingPadding EdgeInsets?
final
floatingStyle AndrossyFieldProperty<TextStyle?>?
final
floatingText String?
final
floatingVisibility FloatingVisibility?
final
focusNode FocusNode?
final
footerStyle AndrossyFieldProperty<TextStyle?>?
final
footerVisibility FloatingVisibility?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
helperStyle AndrossyFieldProperty<TextStyle?>?
final
helperText String?
final
hintColor Color?
final
hintText String?
final
ignorableCharacters String?
final
indicator Widget?
final
indicatorAlignment IndicatorAlignment?
final
indicatorSize double?
final
indicatorStrokeBackground AndrossyFieldProperty<Color?>?
final
indicatorStrokeColor AndrossyFieldProperty<Color?>?
final
indicatorStrokeWidth double?
final
indicatorVisible bool?
final
inputAction TextInputAction?
final
inputFormatters List<TextInputFormatter>?
final
inputType TextInputType?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance Brightness?
final
loadingText String?
final
magnifierConfiguration TextMagnifierConfiguration?
final
maxCharacters int?
final
maxCharactersAsLimit bool?
final
maxLines int?
final
minCharacters int?
final
minLines int?
final
mouseCursor MouseCursor?
final
obscureText bool?
final
obscuringCharacter String?
final
onAppPrivateCommand AndrossyFieldPrivateCommandListener?
final
onChanged OnAndrossyFieldChanged?
final
onCheck OnAndrossyFieldErrorCheck?
CALLBACK LOCAL PROPERTIES
final
onEditingComplete AndrossyFieldVoidListener?
final
onError OnAndrossyFieldError?
final
onSubmitted OnAndrossyFieldChanged?
final
onTapOutside AndrossyFieldTapOutsideListener?
final
onValid OnAndrossyFieldValid?
final
onValidator OnAndrossyFieldValidator?
final
primaryColor Color?
final
readOnly bool?
final
restorationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled bool?
final
scrollController ScrollController?
final
scrollPadding EdgeInsets?
final
scrollPhysics ScrollPhysics?
final
secondaryColor Color?
final
selectionControls TextSelectionControls?
final
selectionHeightStyle BoxHeightStyle?
final
selectionWidthStyle BoxWidthStyle?
final
showCursor bool?
final
smartDashesType SmartDashesType?
final
smartQuotesType SmartQuotesType?
final
spellCheckConfiguration SpellCheckConfiguration?
final
strutStyle StrutStyle?
final
style TextStyle?
final
text String?
final
textAlign TextAlign?
final
textCapitalization TextCapitalization?
final
textDirection TextDirection?
final
underlineColor AndrossyFieldProperty<Color?>?
final
underlineHeight AndrossyFieldProperty<double?>?
final
undoController UndoHistoryController?
final
width double?
GLOBAL PROPERTIES
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossyField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultWith({Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, AndrossyFieldProperty<TextStyle?>? footerStyle, FloatingVisibility? footerVisibility, double? height, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, IndicatorAlignment? indicatorAlignment, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, EdgeInsets? contentPadding, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, double? width, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldContextMenuBuilder? contextMenuBuilder, AndrossyFieldProperty<Color?>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, TextDirection? textDirection, Brightness? keyboardAppearance, bool? enabled, bool? autoDisposeMode, String? characters, AndrossyFieldProperty? drawableEnd, AndrossyFieldDrawableBuilder? drawableEndBuilder, bool? drawableEndVisible, AndrossyFieldTweenProperty? drawableEye, AndrossyFieldProperty? drawableStart, AndrossyFieldDrawableBuilder? drawableStartBuilder, bool? drawableStartVisible, String? errorText, String? floatingText, String? helperText, String? hintText, Widget? indicator, bool? indicatorVisible, String? ignorableCharacters, String? loadingText, int? maxCharacters, bool? maxCharactersAsLimit, int? minCharacters, List<TextInputFormatter>? inputFormatters, String? text, bool? autocorrect, List<String>? autofillHints, bool? autoFocus, TextEditingController? controller, bool? expands, TextInputAction? inputAction, TextInputType? inputType, int? maxLines, int? minLines, bool? obscureText, bool? readOnly, String? restorationId, ScrollController? scrollController, bool? showCursor, TextInputAction? textInputAction, UndoHistoryController? undoController, AndrossyFieldPrivateCommandListener? onAppPrivateCommand, AndrossyFieldVoidListener? onEditingComplete, AndrossyFieldSubmitListener? onSubmitted, AndrossyFieldTapOutsideListener? onTapOutside, OnAndrossyFieldErrorCheck? onCheck, OnAndrossyFieldChanged? onChanged, OnAndrossyFieldError? onError, OnAndrossyFieldValid? onValid, OnAndrossyFieldValidator? onValidator}) AndrossyField
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited