AndrossyFieldProperty<T> class
Constructors
- AndrossyFieldProperty({T? enabled, T? disabled, T? error, T? errorFocused, T? focused, T? loading, T? loadingFocused, T? readOnly, T? valid, T? validFocused})
-
const
- AndrossyFieldProperty.all(T? value)
-
const
- AndrossyFieldProperty.auto()
-
const
- AndrossyFieldProperty.none()
-
const
Properties
- disabled → T?
-
no setter
- enabled → T?
-
final
- error → T?
-
no setter
- errorFocused → T?
-
no setter
- focused → T?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- loading → T?
-
no setter
- loadingFocused → T?
-
no setter
- readOnly → T?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valid → T?
-
no setter
- validFocused → T?
-
no setter
Methods
-
copyWith(
{T? disabled, T? enabled, T? error, T? errorFocused, T? focused, T? loading, T? loadingFocused, T? readOnly, T? valid, T? validFocused}) → AndrossyFieldProperty< T> -
fromState(
AndrossyFieldPropertyState state) → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override