AndrossyFieldState class

Inheritance

Constructors

AndrossyFieldState()

Properties

activated bool
no setter
animationCurve Curve
latefinal
animationDuration Duration?
latefinal
characters String
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
controller TextEditingController
WIDGET BUILDER START
getter/setter pair
counter String
no setter
counterVisibility FloatingVisibility
no setter
counterVisible bool
no setter
defaultBorderColor AndrossyFieldProperty<Color?>
latefinal
defaultCursorColor AndrossyFieldProperty<Color>
latefinal
defaultDrawableEndColor AndrossyFieldProperty<Color?>
latefinal
defaultDrawableStartColor AndrossyFieldProperty<Color?>
latefinal
defaultFloatingStyle AndrossyFieldProperty<TextStyle?>
latefinal
defaultFooterStyle AndrossyFieldProperty<TextStyle?>
latefinal
defaultIndicatorBackgroundColor AndrossyFieldProperty<Color?>
latefinal
defaultIndicatorColor AndrossyFieldProperty<Color?>
latefinal
defaultLabelStyle TextStyle
latefinal
defaultUnderlineColor AndrossyFieldProperty<Color?>
latefinal
drawableEnd → dynamic
DRAWABLE PROPERTIES
no setter
drawableEndSize double
no setter
drawableEndSpace EdgeInsets
no setter
drawableStart → dynamic
no setter
drawableStartSize double
no setter
drawableStartSpace EdgeInsets
no setter
errorColor Color
latefinal
errorText String?
getter/setter pair
floatingAlignment Alignment
no setter
floatingPadding EdgeInsets
no setter
floatingText String
getter/setter pair
floatingTextStyle TextStyle
no setter
floatingVisibility FloatingVisibility
no setter
floatingVisible bool
no setter
footerAlignment MainAxisAlignment
no setter
footerVisible bool
no setter
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
helperText String
getter/setter pair
helperTextVisible bool
no setter
hintStyle TextStyle
getter/setter pair
hintText String
no setter
iEnd → dynamic
OTHERS
no setter
ignorableCharacters String
getter/setter pair
indicatorAlignment IndicatorAlignment
no setter
indicatorSize double
latefinal
isChecked bool
no setter
isEnabled bool
no setter
isError bool
no setter
isFocused bool
no setter
isIndicatorVisible bool
no setter
isInitial bool
no setter
isReadMode bool
no setter
iStart → dynamic
no setter
isUnderlineHide bool
no setter
isValid bool
no setter
maxCharacters int
PROPERTY STATE END BASE CALLBACK START
getter/setter pair
maxCharactersAsLimit bool
getter/setter pair
maxLines int?
no setter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
obscureText bool
no setter
onAppPrivateCommand AndrossyFieldPrivateCommandListener?
no setter
onChange OnAndrossyFieldChanged?
no setter
onCheck OnAndrossyFieldErrorCheck?
CALLBACK PROPERTIES
no setter
onEditingComplete AndrossyFieldVoidListener?
no setter
onError OnAndrossyFieldError?
no setter
onSubmitted AndrossyFieldSubmitListener?
no setter
onTapOutside AndrossyFieldTapOutsideListener?
no setter
onValid OnAndrossyFieldValid?
no setter
onValidator OnAndrossyFieldValidator?
no setter
primaryColor Color
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
latefinal
state AndrossyFieldPropertyState
getter/setter pair
style TextStyle
getter/setter pair
text String
no setter
theme ThemeData
latefinal
underlineHeight double
no setter
validate bool
no setter
widget AndrossyField
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addFocusListener([VoidCallback? callback]) → void
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultIndicator(AndrossyFieldPropertyState state) Widget
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant AndrossyField oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
errorType(String text, [bool? valid]) AndrossyFieldError
hideKeyboard(BuildContext context) → void
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify([VoidCallback? callback]) → void
onChangeEye() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeFocusListener([VoidCallback? callback]) → void
setEnabled(bool value) → void
setError(bool value) → void
setErrorText(String? value) → void
setFocused(bool value) → void
setHelperText(String? value) → void
setHintText(String? value) → void
setIndicatorVisibility(bool visible) → void
setOnValidListener(OnAndrossyFieldValid value) → void
setReadMode(bool value) → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showKeyboard(BuildContext context) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
update() → void
BASE NOTIFIER END NOTIFIERS START

Operators

operator ==(Object other) bool
The equality operator.
inherited