AndrossyForm class

Inheritance

Constructors

AndrossyForm({Key? key, AndrossyFormController? controller, int? initialCheckTime, OnAndrossyFieldValid? onValid, List<Widget> children = const [], Axis direction = Axis.vertical, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.min, TextBaseline? textBaseline, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, EdgeInsets? contentPadding, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, AndrossyFieldProperty<TextStyle?>? footerStyle, FloatingVisibility? footerVisibility, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldContextMenuBuilder? contextMenuBuilder, AndrossyFieldProperty<Color>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, Brightness? keyboardAppearance})

Properties

animationCurve Curve?
CHILDREN PROPERTIES FIELD PROPERTIES
final
animationDuration Duration?
final
backgroundColor AndrossyFieldProperty<Color?>?
final
borderColor AndrossyFieldProperty<Color?>?
final
borderRadius AndrossyFieldProperty<BorderRadius?>?
final
borderWidth AndrossyFieldTweenProperty<double?>?
final
children List<Widget>
final
clipBehavior Clip?
TEXT FIELD PROPERTIES
final
constraints BoxConstraints?
final
contentInsertionConfiguration ContentInsertionConfiguration?
final
contentPadding EdgeInsets?
final
contextMenuBuilder AndrossyFieldContextMenuBuilder?
final
controller AndrossyFormController
final
counterStyle AndrossyFieldProperty<TextStyle?>?
final
counterVisibility FloatingVisibility?
final
crossAxisAlignment CrossAxisAlignment
final
cursorColor AndrossyFieldProperty<Color>?
final
cursorHeight double?
final
cursorOpacityAnimates bool?
final
cursorRadius Radius?
final
cursorWidth double?
final
decoration AndrossyFieldProperty<BoxDecoration?>?
final
direction Axis
final
dragStartBehavior DragStartBehavior?
final
drawableEndPadding AndrossyFieldProperty<double?>?
final
drawableEndSize AndrossyFieldProperty<double?>?
final
drawableEndTint AndrossyFieldProperty<Color?>?
final
drawableStartPadding AndrossyFieldProperty<double?>?
final
drawableStartSize AndrossyFieldProperty<double?>?
final
drawableStartTint AndrossyFieldProperty<Color?>?
final
enableIMEPersonalizedLearning bool?
final
enableInteractiveSelection bool?
final
enableSuggestions bool?
final
errorColor Color?
final
errorStyle AndrossyFieldProperty<TextStyle?>?
final
floatingAlignment Alignment?
final
floatingPadding EdgeInsets?
final
floatingStyle AndrossyFieldProperty<TextStyle?>?
final
floatingVisibility FloatingVisibility?
final
focusNode FocusNode?
final
footerStyle AndrossyFieldProperty<TextStyle?>?
final
footerVisibility FloatingVisibility?
final
hashCode int
The hash code for this object.
no setterinherited
helperStyle AndrossyFieldProperty<TextStyle?>?
final
hintColor Color?
final
indicatorSize double?
final
indicatorStrokeBackground AndrossyFieldProperty<Color?>?
final
indicatorStrokeColor AndrossyFieldProperty<Color?>?
final
indicatorStrokeWidth double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance Brightness?
final
magnifierConfiguration TextMagnifierConfiguration?
final
mainAxisAlignment MainAxisAlignment
final
mainAxisSize MainAxisSize
final
mouseCursor MouseCursor?
final
obscuringCharacter String?
final
primaryColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled bool?
final
scrollPadding EdgeInsets?
final
scrollPhysics ScrollPhysics?
final
secondaryColor Color?
final
selectionControls TextSelectionControls?
final
selectionHeightStyle BoxHeightStyle?
final
selectionWidthStyle BoxWidthStyle?
final
smartDashesType SmartDashesType?
final
smartQuotesType SmartQuotesType?
final
spellCheckConfiguration SpellCheckConfiguration?
final
strutStyle StrutStyle?
final
style TextStyle?
final
textAlign TextAlign?
final
textBaseline TextBaseline?
final
textCapitalization TextCapitalization?
final
textDirection TextDirection?
final
underlineColor AndrossyFieldProperty<Color?>?
final
underlineHeight AndrossyFieldProperty<double?>?
final
verticalDirection VerticalDirection
final

Methods

copyWith({AndrossyFormController? controller, Axis? direction, CrossAxisAlignment? crossAxisAlignment, MainAxisAlignment? mainAxisAlignment, MainAxisSize? mainAxisSize, TextBaseline? textBaseline, TextDirection? textDirection, VerticalDirection? verticalDirection, List<Widget>? children, Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, EdgeInsets? contentPadding, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, AndrossyFieldProperty<TextStyle?>? footerStyle, FloatingVisibility? footerVisibility, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldContextMenuBuilder? contextMenuBuilder, AndrossyFieldProperty<Color>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, Brightness? keyboardAppearance}) AndrossyForm
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossyForm>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited