GestureAnimation class

Constructors

GestureAnimation({required GestureAnimationBuilder? builder, AnimationBehavior behavior = AnimationBehavior.normal, String? debugLabel = 'custom', Duration duration = const Duration(milliseconds: 130), Curve curve = Curves.linear, Curve? reverseCurve, Duration? reverseDuration, double value = 1.0, double upperBound = 1.0, double lowerBound = 0.0, bool repeat = false, double? begin, double? end})
const
GestureAnimation.depth({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeOut, String? debugLabel = 'depth', Duration duration = const Duration(milliseconds: 300), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double depth = 0.0, double shadowBlur = 20.0, Color? shadowColor, Offset? shadowOffset, BorderRadius? shadowRadius, double shadowSpread = 0.0})
GestureAnimation.elevate({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeOut, String? debugLabel = 'elevate', Duration duration = const Duration(milliseconds: 130), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double liftPixels = 4.0})
GestureAnimation.fade({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'fade', Duration duration = const Duration(milliseconds: 130), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, double target = 0.75, double? end = 1.0, bool repeat = false})
const
GestureAnimation.none()
const
GestureAnimation.pendulum({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'pendulum', Duration duration = const Duration(milliseconds: 400), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double angleDegree = 1.0, int swings = 1})
GestureAnimation.push({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeOut, String? debugLabel = 'push', Duration duration = const Duration(milliseconds: 130), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, required Widget shadow, Offset shadowOffset = const Offset(0, 7)})
GestureAnimation.rotate({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'rotate', Duration duration = const Duration(milliseconds: 130), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, double target = 1.01, double end = 1.0, bool repeat = false})
const
GestureAnimation.scale({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'scale', Duration duration = const Duration(milliseconds: 130), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, double target = 0.95, double? end = 1.0, bool repeat = false})
const
GestureAnimation.shake({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'shake', Duration duration = const Duration(milliseconds: 400), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double intensity = 4.0, int shakes = 3})
GestureAnimation.swing({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'swing', Duration duration = const Duration(milliseconds: 1500), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double angleDegree = 1.0, double chainLength = 1.0, int swings = 1})
GestureAnimation.wave({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.linear, String? debugLabel = 'wave', Duration duration = const Duration(milliseconds: 400), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double amplitude = 1.0, int waves = 1, bool horizontal = false})
GestureAnimation.wiggle({AnimationBehavior behavior = AnimationBehavior.normal, Curve curve = Curves.easeInOut, String? debugLabel = 'wiggle', Duration duration = const Duration(milliseconds: 400), Curve? reverseCurve, Duration? reverseDuration, double upperBound = 1.0, double lowerBound = 0.0, double value = 1.0, bool repeat = false, double angleDeg = 5.0, int wiggles = 3})

Properties

begin double?
final
behavior AnimationBehavior
final
builder GestureAnimationBuilder?
final
curve Curve
final
debugLabel String?
final
duration Duration
final
end double?
final
hashCode int
The hash code for this object.
no setteroverride
isActivated bool
no setter
lowerBound double
final
repeat bool
final
reverseCurve Curve?
final
reverseDuration Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upperBound double
final
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override