AndrossyOption class

Inheritance

Constructors

AndrossyOption({Key? key, Axis direction = Axis.vertical, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.min, TextBaseline? textBaseline, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, Clip clipBehavior = Clip.none, AndrossyOptionProperty<int>? flex, required AndrossyOptionBuilder builder, int currentIndex = 0, int itemCount = 0, double spaceBetween = 0, AndrossyOptionCallback? gesture, AndrossyOptionChanged? onChanged})
const

Properties

builder AndrossyOptionBuilder
final
clipBehavior Clip
final
crossAxisAlignment CrossAxisAlignment
final
currentIndex int
final
direction Axis
final
flex AndrossyOptionProperty<int>?
final
gesture AndrossyOptionCallback?
final
hashCode int
The hash code for this object.
no setterinherited
itemCount int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment MainAxisAlignment
final
mainAxisSize MainAxisSize
final
onChanged AndrossyOptionChanged?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceBetween double
final
textBaseline TextBaseline?
final
textDirection TextDirection?
final
verticalDirection VerticalDirection
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossyOption>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited