AndrossySelection<T> class

Inheritance

Constructors

AndrossySelection({Key? key, TextEditingController? controller, AndrossySelectionSearchBuilder<T>? searchBuilder, List<T> items = const [], bool singleMode = false, bool filterMode = false, Iterable<String> initialTags = const {}, required ValueChanged<List<String>> onSelectedTags, required AndrossySelectionBuilder<T> builder, required AndrossySelectionTagBuilder<T> tagBuilder, AndrossySelectionListBuilder<T>? listBuilder, Axis direction = Axis.horizontal, WrapAlignment alignment = WrapAlignment.start, double spacing = 8.0, WrapAlignment runAlignment = WrapAlignment.start, double runSpacing = 8.0, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, Clip clipBehavior = Clip.none})
const

Properties

alignment WrapAlignment
final
builder AndrossySelectionBuilder<T>
final
clipBehavior Clip
final
controller TextEditingController?
final
crossAxisAlignment WrapCrossAlignment
final
direction Axis
final
filterMode bool
final
hashCode int
The hash code for this object.
no setterinherited
initialTags Iterable<String>
final
items List<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listBuilder AndrossySelectionListBuilder<T>?
final
onSelectedTags ValueChanged<List<String>>
final
runAlignment WrapAlignment
final
runSpacing double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBuilder AndrossySelectionSearchBuilder<T>?
final
singleMode bool
final
spacing double
final
tagBuilder AndrossySelectionTagBuilder<T>
final
textDirection TextDirection?
final
verticalDirection VerticalDirection
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossySelection<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited