PositionType enum

Inheritance
Available extensions

Values

left → const PositionType

Left positions

leftTop → const PositionType
leftBottom → const PositionType
leftFlex → const PositionType

Right positions

rightTop → const PositionType
rightBottom → const PositionType
rightFlex → const PositionType
top → const PositionType

Top positions

topLeft → const PositionType
topRight → const PositionType
topFlex → const PositionType
bottom → const PositionType

Bottom positions

bottomLeft → const PositionType
bottomRight → const PositionType
bottomFlex → const PositionType
center → const PositionType

Center positions

fill → const PositionType
fillX → const PositionType
fillY → const PositionType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PositionType>
A constant List of the values in this enum, in order of their declaration.