AndrossyTab class

Inheritance

Constructors

AndrossyTab({Key? key, TabController? controller, required Widget builder(BuildContext context, int index, bool selected), bool automaticIndicatorColorAdjustment = true, Color? dividerColor, double? dividerHeight, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool? enableFeedback, Decoration? indicator, Color? indicatorColor, bool indicatorFullWidth = false, EdgeInsets indicatorPadding = EdgeInsets.zero, double indicatorWeight = 2, bool isScrollable = false, EdgeInsets? margin, MouseCursor? mouseCursor, ValueChanged<int>? onChanged, WidgetStateProperty<Color?>? overlayColor, EdgeInsets? padding, ScrollPhysics? physics, BorderRadius? splashBorderRadius, InteractiveInkFeatureFactory? splashFactory, TabAlignment? tabAlignment, TextScaler? textScaler})
const

Properties

automaticIndicatorColorAdjustment bool
final
builder Widget Function(BuildContext context, int index, bool selected)
final
controller TabController?
final
dividerColor Color?
final
dividerHeight double?
final
dragStartBehavior DragStartBehavior
final
enableFeedback bool?
final
hashCode int
The hash code for this object.
no setterinherited
indicator Decoration?
final
indicatorColor Color?
final
indicatorFullWidth bool
final
indicatorPadding EdgeInsets
final
indicatorWeight double
final
isScrollable bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsets?
final
mouseCursor MouseCursor?
final
onChanged ValueChanged<int>?
final
overlayColor WidgetStateProperty<Color?>?
final
padding EdgeInsets?
final
physics ScrollPhysics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashBorderRadius BorderRadius?
final
splashFactory InteractiveInkFeatureFactory?
final
tabAlignment TabAlignment?
final
textScaler TextScaler?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossyTab>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited