AndrossyButton class

Inheritance

Constructors

AndrossyButton({Key? key, bool activated = false, bool enabled = true, bool loading = false, dynamic icon, AndrossyButtonProperty? icons, IconAlignment iconOrIndicatorAlignment = IconAlignment.end, AndrossyButtonProperty<Color>? iconColor, AndrossyButtonProperty<Color>? indicatorColor, bool autoIconOrIndicatorColorAdjustment = true, bool iconOrIndicatorFlexible = false, bool iconOnly = false, double iconSize = 24, double? iconOrIndicatorSpace, Widget? indicator, double? indicatorSize, double? indicatorStrokeWidth, String? text, AndrossyButtonProperty<String>? texts, bool centerText = false, AndrossyButtonProperty<Color> textColor = const AndrossyButtonProperty(), bool textAllCaps = false, double? textSize, TextStyle? textStyle, AndrossyButtonProperty<Color> backgroundColor = const AndrossyButtonProperty(), double? width, double? height, BoxConstraints? constraints, EdgeInsets padding = const EdgeInsets.all(8), AndrossyButtonProperty<Color> borderColor = const AndrossyButtonProperty(), double borderWidth = 1.5, double borderStrokeAlign = BorderSide.strokeAlignInside, VoidCallback? onDoubleTap, VoidCallback? onLongPress, ValueChanged<bool>? onHover, VoidCallback? onTap, ValueChanged<bool>? onToggle, Color? primary, bool borderOnly = false, BorderRadius? borderRadius, double elevation = 0, Color? elevationColor, bool enableFeedback = true, Color? highlightColor, Color? hoverColor, MouseCursor? mouseCursor, Color? splashColor, InteractiveInkFeatureFactory? splashFactory, WidgetStateProperty<Color?>? overlayColor, AndrossyGestureEffect clickEffect = const AndrossyGestureEffect()})
const

Properties

activated bool
final
autoIconOrIndicatorColorAdjustment bool
final
backgroundColor AndrossyButtonProperty<Color>
final
borderColor AndrossyButtonProperty<Color>
final
borderOnly bool
final
borderRadius BorderRadius?
final
borderStrokeAlign double
final
borderWidth double
final
centerText bool
final
clickEffect AndrossyGestureEffect
final
constraints BoxConstraints?
final
elevation double
final
elevationColor Color?
final
enabled bool
final
enableFeedback bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
highlightColor Color?
final
hoverColor Color?
final
icon → dynamic
final
iconColor AndrossyButtonProperty<Color>?
final
iconOnly bool
final
iconOrIndicatorAlignment IconAlignment
final
iconOrIndicatorFlexible bool
final
iconOrIndicatorSpace double?
final
icons AndrossyButtonProperty?
final
iconSize double
final
indicator Widget?
final
indicatorColor AndrossyButtonProperty<Color>?
final
indicatorSize double?
final
indicatorStrokeWidth double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading bool
final
mouseCursor MouseCursor?
final
onDoubleTap VoidCallback?
final
onHover ValueChanged<bool>?
final
onLongPress VoidCallback?
final
onTap VoidCallback?
final
onToggle ValueChanged<bool>?
final
overlayColor WidgetStateProperty<Color?>?
final
padding EdgeInsets
final
primary Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
final
splashFactory InteractiveInkFeatureFactory?
final
text String?
final
textAllCaps bool
final
textColor AndrossyButtonProperty<Color>
final
texts AndrossyButtonProperty<String>?
final
textSize double?
final
textStyle TextStyle?
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossyButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited