AndrossyButton class

Inheritance

Constructors

AndrossyButton({Key? key, int animation = 0, Curve animationCurve = Curves.linear, ImageFilter? backdropFilter, BlendMode? backdropMode, Color? color, BoxDecoration? decoration, ShapeBorder? decorationShape, BoxDecoration? foregroundDecoration, ShapeBorder? foregroundDecorationShape, CustomClipper? clipper, AndrossyPainterConfig? clipConfig, Clip? clipBehavior, double? aspectRatio, int? flex, double? opacity, bool opacityAlwaysIncludeSemantics = false, bool visibility = true, CustomPainter? painter, AndrossyPainterConfig? painterConfig, bool absorbPointer = false, bool ignorePointer = false, Alignment? alignment, ViewPosition? position, ViewPositionType? positionType, void onRenderedSize(Size)?, BlendMode shaderBlendMode = BlendMode.modulate, ShaderCallback? shaderCallback, Gradient? shaderGradient, List<BoxShadow>? shadows, BoxConstraints? constraints, double? height, double? width, EdgeInsets? margin, EdgeInsets? padding, Matrix4? transform, AlignmentGeometry? transformAlignment, double elevation = 0, bool enabled = true, bool haptic = true, Color? highlightColor, Color? hoverColor, Color? splashColor, GestureClickEffect? clickEffect, OnAndrossyGestureClickListener? onClick, OnAndrossyGestureClickListener? onDoubleClick, OnAndrossyGestureClickListener? onLongClick, void onHover(bool status)?, dynamic icon, IconAlignment iconAlignment = IconAlignment.end, Color? iconColor, bool iconColorAsRoot = false, bool iconFlexible = false, bool iconOnly = false, double? iconSize, double? iconSpace, String? text, bool textAllCaps = true, bool textCenter = false, Color? textColor, FontWeight? textFontWeight, double? textSize, TextStyle? textStyle, bool activated = false})
const

Properties

absorbPointer bool
finalinherited
activated bool
final
alignment Alignment?
finalinherited
animation int
finalinherited
animationCurve Curve
finalinherited
aspectRatio double?
finalinherited
backdropFilter ImageFilter?
finalinherited
backdropMode BlendMode?
finalinherited
child Widget?
finalinherited
clickEffect GestureClickEffect?
finalinherited
clipBehavior Clip?
finalinherited
clipConfig AndrossyPainterConfig?
finalinherited
clipper CustomClipper?
finalinherited
color Color?
finalinherited
constraints BoxConstraints?
finalinherited
decoration BoxDecoration?
finalinherited
decorationShape ShapeBorder?
finalinherited
elevation double
finalinherited
enabled bool
finalinherited
flex int?
finalinherited
foregroundDecoration BoxDecoration?
finalinherited
foregroundDecorationShape ShapeBorder?
finalinherited
haptic bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
finalinherited
highlightColor Color?
finalinherited
hoverColor Color?
finalinherited
icon → dynamic
final
iconAlignment IconAlignment
final
iconColor Color?
final
iconColorAsRoot bool
final
iconFlexible bool
final
iconOnly bool
final
iconSize double?
final
iconSpace double?
final
ignorePointer bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsets?
finalinherited
onClick OnAndrossyGestureClickListener?
finalinherited
onDoubleClick OnAndrossyGestureClickListener?
finalinherited
onHover → void Function(bool status)?
finalinherited
onLongClick OnAndrossyGestureClickListener?
finalinherited
onRenderedSize → void Function(Size)?
finalinherited
opacity double?
finalinherited
opacityAlwaysIncludeSemantics bool
finalinherited
padding EdgeInsets?
finalinherited
painter CustomPainter?
finalinherited
painterConfig AndrossyPainterConfig?
finalinherited
position ViewPosition?
finalinherited
positionType ViewPositionType?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shaderBlendMode BlendMode
finalinherited
shaderCallback ShaderCallback?
finalinherited
shaderGradient Gradient?
finalinherited
shadows List<BoxShadow>?
finalinherited
splashColor Color?
finalinherited
text String?
final
textAllCaps bool
final
textCenter bool
final
textColor Color?
final
textFontWeight FontWeight?
final
textSize double?
final
textStyle TextStyle?
final
transform Matrix4?
finalinherited
transformAlignment AlignmentGeometry?
finalinherited
visibility bool
finalinherited
width double?
finalinherited

Methods

attach(BuildContext context) Widget
override
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultTheme(BuildContext context) ViewTheme
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited