AndrossyField class
Constructors
-
AndrossyField({Key? key, Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, EdgeInsets? contentPadding, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, double? height, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, IndicatorAlignment? indicatorAlignment, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, String? loadingText, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, double? width, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldProperty<Color?>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, TextDirection? textDirection, Brightness? keyboardAppearance, bool? enabled, bool? autoDisposeMode, String? characters, AndrossyFieldProperty? drawableEnd, AndrossyFieldDrawableBuilder? drawableEndBuilder, bool? drawableEndVisible, AndrossyFieldTweenProperty? drawableEye, AndrossyFieldProperty? drawableStart, AndrossyFieldDrawableBuilder? drawableStartBuilder, bool? drawableStartVisible, String? errorText, String? floatingText, String? helperText, String? hintText, Widget? indicator, bool? indicatorVisible, String? ignorableCharacters, int? maxCharacters, bool? maxCharactersAsLimit, int? minCharacters, List<TextInputFormatter>? inputFormatters, String? text, bool? autocorrect, List<String>? autofillHints, bool? autoFocus, TextEditingController? controller, bool? expands, TextInputAction? inputAction, TextInputType? inputType, int? maxLines, int? minLines, bool? obscureText, bool? readOnly, String? restorationId, ScrollController? scrollController, bool? showCursor, UndoHistoryController? undoController, AndrossyFieldPrivateCommandListener? onAppPrivateCommand, AndrossyFieldVoidListener? onEditingComplete, AndrossyFieldSubmitListener? onSubmitted, AndrossyFieldTapOutsideListener? onTapOutside, OnAndrossyFieldErrorCheck? onCheck, OnAndrossyFieldChanged? onChanged, OnAndrossyFieldError? onError, OnAndrossyFieldValid? onValid, OnAndrossyFieldValidator? onValidator})
-
const
Methods
-
createElement()
→ StatefulElement
-
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState()
→ State<AndrossyField>
-
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
defaultWith({Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, double? height, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, IndicatorAlignment? indicatorAlignment, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, EdgeInsets? contentPadding, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, double? width, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldProperty<Color?>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, TextDirection? textDirection, Brightness? keyboardAppearance, bool? enabled, bool? autoDisposeMode, String? characters, AndrossyFieldProperty? drawableEnd, AndrossyFieldDrawableBuilder? drawableEndBuilder, bool? drawableEndVisible, AndrossyFieldTweenProperty? drawableEye, AndrossyFieldProperty? drawableStart, AndrossyFieldDrawableBuilder? drawableStartBuilder, bool? drawableStartVisible, String? errorText, String? floatingText, String? helperText, String? hintText, Widget? indicator, bool? indicatorVisible, String? ignorableCharacters, String? loadingText, int? maxCharacters, bool? maxCharactersAsLimit, int? minCharacters, List<TextInputFormatter>? inputFormatters, String? text, bool? autocorrect, List<String>? autofillHints, bool? autoFocus, TextEditingController? controller, bool? expands, TextInputAction? inputAction, TextInputType? inputType, int? maxLines, int? minLines, bool? obscureText, bool? readOnly, String? restorationId, ScrollController? scrollController, bool? showCursor, TextInputAction? textInputAction, UndoHistoryController? undoController, AndrossyFieldPrivateCommandListener? onAppPrivateCommand, AndrossyFieldVoidListener? onEditingComplete, AndrossyFieldSubmitListener? onSubmitted, AndrossyFieldTapOutsideListener? onTapOutside, OnAndrossyFieldErrorCheck? onCheck, OnAndrossyFieldChanged? onChanged, OnAndrossyFieldError? onError, OnAndrossyFieldValid? onValid, OnAndrossyFieldValidator? onValidator})
→ AndrossyField
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited