AndrossyFieldError enum

Inheritance
Available extensions

Values

none → const AndrossyFieldError
alreadyFound → const AndrossyFieldError
empty → const AndrossyFieldError
error → const AndrossyFieldError
invalid → const AndrossyFieldError
maximum → const AndrossyFieldError
minimum → const AndrossyFieldError
networkError → const AndrossyFieldError
unmodified → const AndrossyFieldError

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isAlreadyFound bool
no setter
isEmpty bool
no setter
isError bool
no setter
isInvalid bool
no setter
isMaximum bool
no setter
isMinimum bool
no setter
isNetworkError bool
no setter
isOk bool
no setter
isUnmodified bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AndrossyFieldError>
A constant List of the values in this enum, in order of their declaration.