AndrossyForm class
Constructors
-
AndrossyForm({Key? key, AndrossyFormController? controller, int? initialCheckTime, OnAndrossyFieldValid? onValid, List<Widget> children = const [], Axis direction = Axis.vertical, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, MainAxisSize mainAxisSize = MainAxisSize.min, TextBaseline? textBaseline, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, EdgeInsets? contentPadding, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldProperty<Color>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, Brightness? keyboardAppearance})
-
Methods
-
copyWith({AndrossyFormController? controller, Axis? direction, CrossAxisAlignment? crossAxisAlignment, MainAxisAlignment? mainAxisAlignment, MainAxisSize? mainAxisSize, TextBaseline? textBaseline, TextDirection? textDirection, VerticalDirection? verticalDirection, List<Widget>? children, Curve? animationCurve, Duration? animationDuration, AndrossyFieldProperty<Color?>? backgroundColor, AndrossyFieldProperty<Color?>? borderColor, AndrossyFieldProperty<BorderRadius?>? borderRadius, AndrossyFieldTweenProperty<double?>? borderWidth, BoxConstraints? constraints, EdgeInsets? contentPadding, AndrossyFieldProperty<TextStyle?>? counterStyle, FloatingVisibility? counterVisibility, AndrossyFieldProperty<BoxDecoration?>? decoration, AndrossyFieldProperty<double?>? drawableEndSize, AndrossyFieldProperty<double?>? drawableEndPadding, AndrossyFieldProperty<Color?>? drawableEndTint, AndrossyFieldProperty<double?>? drawableStartSize, AndrossyFieldProperty<double?>? drawableStartPadding, AndrossyFieldProperty<Color?>? drawableStartTint, Color? errorColor, AndrossyFieldProperty<TextStyle?>? errorStyle, Alignment? floatingAlignment, EdgeInsets? floatingPadding, AndrossyFieldProperty<TextStyle?>? floatingStyle, FloatingVisibility? floatingVisibility, FocusNode? focusNode, AndrossyFieldProperty<TextStyle?>? helperStyle, Color? hintColor, double? indicatorSize, double? indicatorStrokeWidth, AndrossyFieldProperty<Color?>? indicatorStrokeBackground, AndrossyFieldProperty<Color?>? indicatorStrokeColor, Color? primaryColor, Color? secondaryColor, StrutStyle? strutStyle, AndrossyFieldProperty<Color?>? underlineColor, AndrossyFieldProperty<double?>? underlineHeight, Clip? clipBehavior, ContentInsertionConfiguration? contentInsertionConfiguration, AndrossyFieldProperty<Color>? cursorColor, double? cursorHeight, bool? cursorOpacityAnimates, Radius? cursorRadius, double? cursorWidth, DragStartBehavior? dragStartBehavior, bool? enableIMEPersonalizedLearning, bool? enableInteractiveSelection, bool? enableSuggestions, TextMagnifierConfiguration? magnifierConfiguration, MouseCursor? mouseCursor, String? obscuringCharacter, bool? scribbleEnabled, EdgeInsets? scrollPadding, ScrollPhysics? scrollPhysics, TextSelectionControls? selectionControls, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, SpellCheckConfiguration? spellCheckConfiguration, TextStyle? style, TextAlign? textAlign, TextCapitalization? textCapitalization, Brightness? keyboardAppearance})
→ AndrossyForm
-
-
createElement()
→ StatefulElement
-
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState()
→ State<AndrossyForm>
-
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited