AndrossyGesture class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AndrossyGesture
Constructors
-
AndrossyGesture({Key? key, bool visibility = true, double elevation = 0, Color? elevationColor, BorderRadiusGeometry? borderRadius, Color? backgroundColor, Clip? clipBehavior, bool enabled = true, bool enableFeedback = true, MaterialType? materialType, MouseCursor? mouseCursor, WidgetStateProperty<
Color?> ? overlayColor, ShapeBorder? shape, Color? splashColor, InteractiveInkFeatureFactory? splashFactory, Color? hoverColor, Color? highlightColor, List<GestureAnimation> ? effects, GestureTapCallback? onTap, GestureTapUpCallback? onTapUp, GestureTapDownCallback? onTapDown, GestureTapCancelCallback? onTapCancel, GestureDoubleTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureLongPressStartCallback? onLongPressStart, GestureLongPressEndCallback? onLongPressEnd, GestureLongPressCancelCallback? onLongPressCancel, ValueChanged<bool> ? onHover, required Widget child}) -
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- child → Widget
-
final
- clipBehavior → Clip?
-
final
-
effects
→ List<
GestureAnimation> ? -
final
- elevation → double
-
final
- elevationColor → Color?
-
final
- enabled → bool
-
final
- enableFeedback → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color?
-
final
- hoverColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- materialType → MaterialType?
-
final
- mouseCursor → MouseCursor?
-
final
- onDoubleTap → GestureDoubleTapCallback?
-
final
-
onHover
→ ValueChanged<
bool> ? -
final
- onLongPress → GestureLongPressCallback?
-
final
- onLongPressCancel → GestureLongPressCancelCallback?
-
final
- onLongPressEnd → GestureLongPressEndCallback?
-
final
- onLongPressStart → GestureLongPressStartCallback?
-
final
- onTap → GestureTapCallback?
-
final
- onTapCancel → GestureTapCancelCallback?
-
final
- onTapDown → GestureTapDownCallback?
-
final
- onTapUp → GestureTapUpCallback?
-
final
-
overlayColor
→ WidgetStateProperty<
Color?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → ShapeBorder?
-
final
- splashColor → Color?
-
final
- splashFactory → InteractiveInkFeatureFactory?
-
final
- visibility → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AndrossyGesture> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited